==> login_firebase-0.0.2.tar.gz: lib/presentation/factories/LoginWidgetFactory.dart <==
import 'package:flutter/material.dart';
import 'package:login_firebase/presentation/resources/LoginColors.dart';
import 'package:login_firebase/presentation/resources/LoginStyles.dart';
import 'package:login_firebase/presentation/theme/LoginTheme.dart';
import 'package:login_firebase/presentation/theme/data/LoginButtonThemeData.dart';
import 'package:login_firebase/presentation/theme/data/LoginThemeData.dart';


abstract class LoginWidgetFactory {
  
  static Widget buildEmptyVerticalSeparator({required double height}) {
    return SizedBox(height: height);
  }

  static Widget buildEmptyHorizontalSeparator({required double width}) {
    return SizedBox(width: width,);
  }

  static Widget buildSigninBtn({
    required BuildContext context,
    required Widget icon,
    required String text,
    required Function() onClick,
    required Color containerColor,
    required Color textColor,
    Color borderColor = LoginColors.lightGreyColor,
    }) {

    LoginThemeData? loginThemeData = LoginTheme.of(context);
    LoginButtonThemeData loginButtonThemeData =
        loginThemeData?.loginButtonThemeData ??
            LoginButtonThemeData.roundedRectangle(borderColor: borderColor);

    return ElevatedButton(
      style: ElevatedButton.styleFrom(
        backgroundColor: containerColor,
        padding: EdgeInsets.symmetric(horizontal: 16),
        shape: RoundedRectangleBorder(
          borderRadius: BorderRadius.all(Radius.circular(25)),
        ),
      ).merge(
        ButtonStyle(elevation: MaterialStateProperty.resolveWith<double>((Set<MaterialState> states) {
          if (states.contains(MaterialState.pressed)) return loginButtonThemeData.elevation ?? 0;
          return 0;
        })),
      ),
      onPressed: () {
        onClick.call();
      },
      child: _buildButtonContent(icon, text, textColor),
    );
  }


  static _buildButtonContent(Widget icon, String text, Color textColor) => Padding(
    padding: EdgeInsets.all(12.0),
    child: Row(
      mainAxisSize: MainAxisSize.max,
      children: <Widget>[
        icon,
        Expanded(
            child: Align(
                alignment: Alignment.center,
                child: Padding(
                    padding: EdgeInsets.symmetric(horizontal: 4.0),
                    child: Text(text, style: SessionStyles.buttonStyle.copyWith(color: textColor))
                )
            )
        ),
      ],
    ),
  );
}

==> login_firebase-0.0.4.tar.gz: lib/presentation/factories/LoginWidgetFactory.dart <==
import 'package:flutter/material.dart';
import 'package:login_firebase/presentation/resources/LoginColors.dart';
import 'package:login_firebase/presentation/resources/LoginStyles.dart';
import 'package:login_firebase/presentation/theme/LoginTheme.dart';
import 'package:login_firebase/presentation/theme/data/LoginButtonThemeData.dart';
import 'package:login_firebase/presentation/theme/data/LoginThemeData.dart';


abstract class LoginWidgetFactory {
  
  static Widget buildEmptyVerticalSeparator({required double height}) {
    return SizedBox(height: height);
  }

  static Widget buildEmptyHorizontalSeparator({required double width}) {
    return SizedBox(width: width,);
  }

  static Widget buildSigninBtn({
    required BuildContext context,
    required Widget icon,
    required String text,
    required Function() onClick,
    required Color containerColor,
    required Color textColor,
    Color borderColor = LoginColors.lightGreyColor,
    }) {

    LoginThemeData? loginThemeData = LoginTheme.of(context);
    LoginButtonThemeData loginButtonThemeData =
        loginThemeData?.loginButtonThemeData ??
            LoginButtonThemeData.roundedRectangle(borderColor: borderColor);

    return ElevatedButton(
      style: ElevatedButton.styleFrom(
        backgroundColor: containerColor,
        padding: const EdgeInsets.symmetric(horizontal: 16),
        shape: const RoundedRectangleBorder(
          borderRadius: BorderRadius.all(Radius.circular(25)),
        ),
      ).merge(
        ButtonStyle(elevation: MaterialStateProperty.resolveWith<double>((Set<MaterialState> states) {
          if (states.contains(MaterialState.pressed)) return loginButtonThemeData.elevation ?? 0;
          return 0;
        })),
      ),
      onPressed: () {
        onClick.call();
      },
      child: _buildButtonContent(icon, text, textColor),
    );
  }


  static _buildButtonContent(Widget icon, String text, Color textColor) => Padding(
    padding: const EdgeInsets.all(12.0),
    child: Row(
      mainAxisSize: MainAxisSize.max,
      children: <Widget>[
        icon,
        Expanded(
            child: Align(
                alignment: Alignment.center,
                child: Padding(
                    padding: const EdgeInsets.symmetric(horizontal: 4.0),
                    child: Text(text, style: SessionStyles.buttonStyle.copyWith(color: textColor))
                )
            )
        ),
      ],
    ),
  );
}
